@@ -1,4 +1,4 @@
-(*i $Id: check.ml,v 1.43 2004/10/22 16:31:03 conchon Exp $ i*)
+(*i $Id: check.ml,v 1.46 2006-05-12 14:07:16 filliatr Exp $ i*)
 
 open Graph
 
@@ -19,6 +19,82 @@ module W = struct
   let compare = compare
 end
 
+
+(********************************************)
+(* Generic functions                        *)
+(********************************************)
+
+module Generic = struct
+
+  (* nb_vertex and nb_edges *)
+
+  module Make
+    (G : Sig.I with type V.t = int)
+    (V : sig val v: int val e: int end) = 
+  struct
+    let g = G.create ()
+    let () =
+      G.add_edge g 1 2;
+      G.add_edge g 1 3;
+      G.add_edge g 2 1;
+      G.add_edge g 2 2;
+      G.add_edge g 2 2;
+      assert (G.nb_vertex g = V.v && G.nb_edges g = V.e);
+  end
+
+  let () =
+    let module D = Make
+      (Imperative.Digraph.ConcreteLabeled(Int)(Int))
+      (struct let v = 3 let e = 4 end)
+    in
+    let module G = Make
+      (Imperative.Graph.ConcreteLabeled(Int)(Int))
+      (struct let v = 3 let e = 3 end)
+    in
+    ()
+
+  (* find_edge *)
+
+  module Make2
+    (G : Sig.I 
+     with type V.t = int and type E.label = int and type E.t = int * int * int)
+    =
+  struct
+
+    let g = G.create ()
+
+    let test_exn v1 v2 =
+      try
+	let _ = G.find_edge g v1 v2 in
+	assert false
+      with Not_found ->
+	()
+
+    let () =
+      let e1 = 1, 0, 2 in
+      let e2 = 1, 1, 3 in
+      let e3 = 2, 2, 1 in
+      let e4 = 2, 1, 2 in
+      G.add_edge_e g e1;
+      G.add_edge_e g e2;
+      G.add_edge_e g e3;
+      G.add_edge_e g e3;
+      assert (G.find_edge g 1 2 = e1);
+      test_exn 2 3;
+      test_exn 2 4;
+      test_exn 5 2
+
+  end
+
+  let () =
+    let module D = Make2(Imperative.Digraph.ConcreteLabeled(Int)(Int)) in
+    D.test_exn 3 1;
+    let module G = Imperative.Graph.ConcreteLabeled(Int)(Int) in
+    let module G2 = Make2(G) in
+    assert (G.find_edge G2.g 3 1 = (3, 1, 1))
+
+end
+
 (********************************************)
 (* Dijkstra                                 *)
 (********************************************)
@@ -316,7 +392,7 @@ end
 (* check that signature [Sig_pack.S] (which is manually expanded) does not
    forget anything *)
 module type RightSigPack = sig
-  include Sig.IA with type V.label = int and type E.label = int
+  include Sig.IM with type V.label = int and type E.label = int
   val find_vertex : t -> int -> V.t
   include Oper.S with type g = t
   module Dfs : sig
