@@ -4,11 +4,7 @@ open Graph.Pack.Digraph
    open Graph.Pack.Graph
 *)
 
-let show g =
-  let tmp = Filename.temp_file "graph" ".dot" in
-  dot_output g tmp;
-  ignore (Sys.command ("dot -Tps " ^ tmp ^ " | gv -"));
-  Sys.remove tmp
+let show = display_with_gv
 
 let g = Rand.graph ~v:10 ~e:20 ()
 let () = show g
