@@ -157,6 +157,7 @@ struct
     f, F.sub flot_max flot_init
 end
 
+(*****************************************************************************)
 
 module type G_FORD_FULKERSON = sig
   type t
@@ -172,7 +173,9 @@ module type G_FORD_FULKERSON = sig
   val iter_pred_e : (E.t -> unit) -> t -> V.t -> unit
 end
 
-module Ford_Fulkerson(G: G_FORD_FULKERSON)(F: FLOW with type label = G.E.label) = 
+module Ford_Fulkerson
+  (G: G_FORD_FULKERSON)
+  (F: FLOW with type label = G.E.label) =
 struct
 
   (* redefinition of F *)
@@ -195,38 +198,39 @@ struct
 
     let marked = H.create 997
     let unvisited = Queue.create ()
-		      
+
     let clear () = H.clear marked
 
     let mem = H.mem marked
-		
+
     let set s e tag = 
       assert (not (mem s));
       H.add marked s (e, tag);
       Queue.add s unvisited
-	
+
     let get s : G.E.t * mark =
       let e, tag = H.find marked s in
       (match e with None -> assert false | Some e -> e), tag
-	  
+
     exception Empty = Queue.Empty
     let next () = Queue.pop unvisited
   end
-      
+
   module Result = struct
-    module E = struct
-      type t = G.E.t
-      module U = Util.HTProduct(G.V)(G.V)
-      let equal e1 e2 =
-	U.equal (G.E.src e1, G.E.dst e1) (G.E.src e2, G.E.dst e2)
-      let hash e = U.hash (G.E.src e, G.E.dst e)
-    end
-    module H = Hashtbl.Make(E)
+    module H = 
+      Hashtbl.Make
+	(struct
+	   open G
+	   type t = E.t
+	   module U = Util.HTProduct(V)(V)
+	   let equal e1 e2 = U.equal (E.src e1, E.dst e1) (E.src e2, E.dst e2)
+	   let hash e = U.hash (E.src e, E.dst e)
+	 end)
 
     let create () = H.create 997
-		   
+
     let find = H.find
-		 
+
     let flow r e = 
       try
 	find r e
@@ -234,23 +238,23 @@ struct
 	let f = F.flow (G.E.label e) in
 	H.add r e f;
 	f
-	      
+
     let change op r e f =
       try
 	H.replace r e (op (find r e) f);
       with Not_found ->
 	assert false
-	  
+
     let grow = change F.add
     let reduce = change F.sub
   end
 
   let is_full r e =
     F.compare (F.max_capacity (G.E.label e)) (Result.flow r e) = 0
-								   
+
   let is_empty r e =
     F.compare (F.min_capacity (G.E.label e)) (Result.flow r e) = 0
-					  
+
   let set_flow r s t a =
     let rec loop t =
       if not (G.V.equal s t) then
@@ -260,7 +264,7 @@ struct
 	  | Mark.Minus -> Result.reduce r e a; loop (G.E.dst e)
     in
     loop t
-	  
+
   let grow_flow r s t a =
     let rec loop u b =
       if G.V.equal s u then begin
@@ -321,6 +325,5 @@ struct
     in
     let a = external_loop F.zero in
     (fun e -> try Result.find r e with Not_found -> F.flow (G.E.label e)), a
-      
-end
 
+end
