@@ -14,7 +14,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: graphviz.ml,v 1.3 2005/01/18 09:17:49 filliatr Exp $ *)
+(* $Id: graphviz.ml,v 1.4 2006-05-09 10:19:37 conchon Exp $ *)
 
 (** Interface with {i GraphViz}
 
@@ -49,15 +49,15 @@ type color = int
 let fprint_color ppf color =
   fprintf ppf "\"#%06X\"" color
 
-let fprint_string ppf s =
-  let s' = String.escaped s in
+let fprint_string ppf s = fprintf ppf "\"%s\"" s
+(*  let s' = String.escaped s in
   if s' = s && s <> ""
   then fprintf ppf "%s" s
-  else fprintf ppf "\"%s\"" s'
+  else fprintf ppf "\"%s\"" s'*)
 
 let fprint_string_user ppf s =
-  let s' = String.escaped s in
-    fprintf ppf "\"%s\"" s'
+(*  let s = String.escaped s in*)
+    fprintf ppf "\"%s\"" s
 
 type arrow_style =
   [ `None | `Normal | `Inv | `Dot | `Odot | `Invdot | `Invodot ] 
@@ -257,7 +257,8 @@ module CommonAttributes = struct
     | `Fontsize i -> fprintf ppf "fontsize=%i" i
     | `Label s -> fprintf ppf "label=%a" fprint_string_user s
     | `Labelfontcolor a -> fprintf ppf "labelfontcolor=%a" fprint_color a
-    | `Labelfontname s -> fprintf ppf "labelfontname=\"%s\"" (String.escaped s)
+    | `Labelfontname s -> fprintf ppf "labelfontname=\"%s\"" s 
+	(* (String.escaped s) *)
     | `Labelfontsize i -> fprintf ppf "labelfontsize=%i" i
     | `Style a -> fprintf ppf "style=%a" fprint_edge_style a
 
@@ -282,6 +283,11 @@ module type ENGINE = sig
     (** Attribute of edges provided by the engine. *)
     type edge
 
+    type subgraph = {
+      sg_name : string;
+      sg_attributes : vertex list;
+    }
+
     val fprint_graph:formatter -> graph -> unit
     val fprint_vertex: formatter -> vertex -> unit
     val fprint_edge: formatter -> edge -> unit
@@ -319,6 +325,9 @@ module MakeEngine
 
      val default_edge_attributes: t -> EN.Attributes.edge list
      val edge_attributes: E.t -> EN.Attributes.edge list
+
+     val get_subgraph : V.t -> EN.Attributes.subgraph option
+
   end) = 
 struct
 
@@ -386,6 +395,7 @@ struct
         the CGL language on the formatter [ppf]. 
      *)
     let fprint_graph ppf graph =
+      let subgraphs = Hashtbl.create 7 in 
 
       (* Printing nodes. *)
 
@@ -395,14 +405,47 @@ struct
 	if default_node_attributes  <> [] then
 	  fprintf ppf "node%a;@ " fprint_node_attributes default_node_attributes;
 
-	X.iter_vertex (function node ->
-	  fprintf ppf "%s%a;@ " 
-	    (X.vertex_name node)
-	    fprint_node_attributes (X.vertex_attributes node);
-        ) graph
+	X.iter_vertex 
+          (function node ->
+             begin match X.get_subgraph node with 
+             | None -> ()
+             | Some sg -> 
+                 try 
+                   let (sg,nodes) = Hashtbl.find subgraphs sg.EN.Attributes.sg_name in
+                   Hashtbl.replace subgraphs sg.EN.Attributes.sg_name (sg,node::nodes)
+                 with Not_found -> 
+                   Hashtbl.add subgraphs sg.EN.Attributes.sg_name (sg,[node]) 
+             end;
+	     fprintf ppf "%s%a;@ " 
+	       (X.vertex_name node)
+	       fprint_node_attributes (X.vertex_attributes node)) 
+          graph
 
       in
 
+      (* Printing subgraphs *)
+
+      let print_subgraphs ppf = 
+        
+        Hashtbl.iter
+          (fun name (sg,nodes) -> 
+             fprintf ppf "@[<v 2>subgraph cluster_%s { %t%t };@]@\n"
+               name
+               
+               (fun ppf -> 
+                  (List.iter 
+                     (fun n -> fprintf ppf "%a;@\n" EN.Attributes.fprint_vertex n)
+                     sg.EN.Attributes.sg_attributes))
+               (fun ppf -> 
+                  (List.iter 
+                     (fun n -> fprintf ppf "%s;" (X.vertex_name n))
+                     nodes))
+               
+          )
+          subgraphs 
+        
+      in
+
       (* Printing edges *)
 
       let print_edges ppf =
@@ -412,12 +455,12 @@ struct
 	  fprintf ppf "edge%a;@ " fprint_edge_attributes default_edge_attributes;
 
 	X.iter_edges_e (function edge ->
-	  fprintf ppf "%s %s %s%a;@ "
-	    (X.vertex_name (X.E.src edge))
-	    EN.edge_arrow
-	    (X.vertex_name (X.E.dst edge))
-	    fprint_edge_attributes (X.edge_attributes edge)
-        ) graph
+	                  fprintf ppf "%s %s %s%a;@ "
+	                    (X.vertex_name (X.E.src edge))
+	                    EN.edge_arrow
+	                    (X.vertex_name (X.E.dst edge))
+	                    fprint_edge_attributes (X.edge_attributes edge)
+                       ) graph
 
       in
 
@@ -425,6 +468,7 @@ struct
 	EN.opening
 	fprint_graph_attributes (X.graph_attributes graph);
       fprintf ppf "%t@ " print_nodes;
+      fprintf ppf "%t@ " print_subgraphs;
       fprintf ppf "%t@ " print_edges;
       fprintf ppf "@]}@]"
 
@@ -582,6 +626,11 @@ module DotAttributes = struct
 
 
 
+    type subgraph = {
+      sg_name : string;
+      sg_attributes : vertex list;
+    }
+
   (** {4 Pretty-print of attributes} *)
 
   let rec fprint_string_list ppf = function
@@ -612,7 +661,7 @@ module DotAttributes = struct
     | `Rankdir a -> fprintf ppf "rankdir=%a" fprint_dir a
     | `Ratio a -> fprintf ppf "ratio=%a" fprint_ratio a
     | `Samplepoints i -> fprintf ppf "samplepoints=%i" i
-    | `Url s -> fprintf ppf "URL=\"%s\"" (String.escaped s)
+    | `Url s -> fprintf ppf "URL=\"%s\"" s (*(String.escaped s)*)
 
   let fprint_vertex ppf = function
       #CommonAttributes.vertex as att -> CommonAttributes.fprint_vertex ppf att
@@ -621,7 +670,7 @@ module DotAttributes = struct
     | `Fillcolor a -> fprintf ppf "fillcolor=%a" fprint_color a
     | `Fixedsize b -> fprintf ppf "fixedsize=%b" b
     | `Layer s -> fprintf ppf "layer=%a" fprint_string s
-    | `Url s -> fprintf ppf "URL=\"%s\"" (String.escaped s)
+    | `Url s -> fprintf ppf "URL=\"%s\"" s (*(String.escaped s)*)
     | `Z f -> fprintf ppf "z=%f" f
 
 
@@ -727,6 +776,11 @@ module NeatoAttributes = struct
 
 
 
+    type subgraph = {
+      sg_name : string;
+      sg_attributes : vertex list;
+    }
+
   (** {4 Pretty-print of attributes} *)
 
   let fprint_graph ppf = function
