@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: imperative.mli,v 1.16 2006/02/03 09:27:29 filliatr Exp $ *)
+(* $Id: imperative.mli,v 1.18 2006-05-12 14:07:16 filliatr Exp $ *)
 
 (** Imperative Implementations *)
 
@@ -29,7 +29,7 @@ module type S = sig
     Sig.I with type V.t = V.t and type V.label = V.t and type E.t = V.t * V.t
 
   (** Abstract Imperative Unlabeled Graphs *)
-  module Abstract(V: sig type t end) : Sig.IA with type V.label = V.t
+  module Abstract(V: ANY_TYPE) : Sig.IM with type V.label = V.t
 
   (** Imperative Labeled Graphs *)
   module ConcreteLabeled (V: COMPARABLE)(E: ORDERED_TYPE_DFT) :
@@ -37,8 +37,8 @@ module type S = sig
 	    and type E.t = V.t * E.t * V.t and type E.label = E.t
 
   (** Abstract Imperative Labeled Graphs *)
-  module AbstractLabeled (V: sig type t end)(E: ORDERED_TYPE_DFT) :
-    Sig.IA with type V.label = V.t and type E.label = E.t
+  module AbstractLabeled (V: ANY_TYPE)(E: ORDERED_TYPE_DFT) :
+    Sig.IM with type V.label = V.t and type E.label = E.t
 
 end
 
@@ -69,7 +69,7 @@ module Matrix : sig
 		  and type E.t = int * int
 
     (** Creation. graphs are not resizeable: size is given at creation time.
-      Thus [create] is useless (creates an empty graph); use [make] instead. *)
+        Thus [make] must be used instead of [create] *)
     val make : int -> t
 
     (** Note: [add_vertex] and [remove_vertex] have no effect *)
