@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: oper.ml,v 1.11 2004/11/04 15:39:41 filliatr Exp $ *)
+(* $Id: oper.ml,v 1.13 2005-06-30 10:48:55 filliatr Exp $ *)
 
 (* Basic operations over graphs *)
 
@@ -51,41 +51,27 @@ module Make(B : Builder.S) = struct
 
   module H = Hashtbl.Make(G.V)
 
-  (* copy all vertices of [g] and returns a hash table containing the map *)
-  let copy_with_map g =
-    let h = H.create 97 in
-    let g' =
-      G.fold_vertex 
-	(fun v g' -> 
-	   let v' = G.V.create (G.V.label v) in
-	   H.add h v v'; 
-	   B.add_vertex g' v') 
-	g (B.empty ()) 
-    in
-    g', h
-
   let mirror g =
     if G.is_directed then begin
-      let g', h = copy_with_map g in
-      G.fold_edges_e
-	(fun e g' -> 
-	   let v1 = H.find h (G.E.src e) in
-	   let v2 = H.find h (G.E.dst e) in
-	   B.add_edge_e g' (G.E.create v2 (G.E.label e) v1))
-	g g'
+      let g' = B.empty () in
+        G.fold_edges_e
+	  (fun e g' -> 
+	     let v1 = (G.E.src e) in
+	     let v2 = (G.E.dst e) in
+	     B.add_edge_e g' (G.E.create v2 (G.E.label e) v1))
+	  g g'
     end else
       B.copy g
 
   let complement g =
-    let g', h = copy_with_map g in
-    G.fold_vertex 
+    G.fold_vertex
       (fun v g' ->
 	 G.fold_vertex
-	   (fun w g' -> 
-	      if G.mem_edge g v w then g' 
-	      else B.add_edge g' (H.find h v) (H.find h w))
-	   g g')
-      g g'
+	   (fun w g' ->
+	      if G.mem_edge g v w then g'
+	      else B.add_edge g' v w)
+	 g g')
+      g (B.empty ())
 
   let intersect g1 g2 = 
     G.fold_vertex
@@ -111,7 +97,7 @@ module Make(B : Builder.S) = struct
 	   G.fold_succ_e (fun e g -> B.add_edge_e g e) g1 v (B.add_vertex g v))
 	g1 g2
     in
-    add g1 (add g2 (B.empty ()))
+    add g1 (B.copy g2)
 
 end
 
