@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: oper.mli,v 1.14 2004/11/04 15:39:41 filliatr Exp $ *)
+(* $Id: oper.mli,v 1.15 2005-01-18 16:40:14 signoles Exp $ *)
 
 (** Basic operations over graphs *)
 
@@ -38,7 +38,7 @@ module type S = sig
   val mirror : g -> g
     (** [mirror g] returns a new graph which is the mirror image of [g]:
       each edge from [u] to [v] has been replaced by an edge from [v] to [u].
-      For undirected graphs, it simply returns of copy of [g]. *)
+      For undirected graphs, it simply returns a copy of [g]. *)
 
   val complement : g -> g
     (** [complement g] returns a new graph which is the complement of [g]:
