@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: sig.mli,v 1.20 2005/02/25 13:54:33 signoles Exp $ *)
+(* $Id: sig.mli,v 1.21 2006-05-12 14:07:16 filliatr Exp $ *)
 
 (** Signatures for graph implementations *)
 
@@ -277,13 +277,15 @@ module type MARK = sig
   val set : vertex -> int -> unit
 end
 
-module type IA = sig
+module type IM = sig
   include I
   module Mark : MARK with type graph = t and type vertex = vertex
 end
 
 (** {1 Signature for ordered and hashable types} *)
 
+module type ANY_TYPE = sig type t end
+
 module type ORDERED_TYPE = sig type t val compare : t -> t -> int end
 
 module type ORDERED_TYPE_DFT = sig include ORDERED_TYPE val default : t end
