@@ -15,7 +15,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(* $Id: util.mli,v 1.11 2004/06/28 07:32:55 filliatr Exp $ *)
+(* $Id: util.mli,v 1.12 2005-03-31 13:32:51 filliatr Exp $ *)
 
 open Sig
 
@@ -29,9 +29,9 @@ module CMPProduct(X: COMPARABLE)(Y: COMPARABLE) :
   COMPARABLE with type t = X.t * Y.t
 
 (** Create a vertex type with some data attached to it *)
-module DataV :
-  functor (L : sig type t end) ->
-  functor (V : Sig.COMPARABLE) ->
+module DataV 
+  (L : sig type t end)
+  (V : Sig.COMPARABLE) :
 sig
   type data = L.t
   and label = V.t
